package org.nakedobjects.applib.value;

import java.text.DateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import junit.framework.TestCase;


public class TimeTest extends TestCase {
    public static void main(String[] args) {
        Date date = new Date(3600000 * 14);
        
        Locale.setDefault(Locale.KOREA);
        Locale.setDefault(Locale.US);
        Locale.setDefault(Locale.FRANCE);
               
        TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
        TimeZone.setDefault(TimeZone.getTimeZone("Europe/London"));
        TimeZone.setDefault(TimeZone.getTimeZone("Europe/Paris"));

        TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
        
        DateFormat format = DateFormat.getDateTimeInstance();
        
        System.out.println(date.toString());
        System.out.println(format.format(date));
    }
    
    
    private Time time;

    protected void setUp() throws Exception {
        TimeZone.setDefault(TimeZone.getTimeZone("Europe/London"));
        TestClock.initialize();
        time = new Time(13, 14);
    }

    public void testAdd() {
        Time result = time.add(2, 3);
        assertEquals(17, result.getMinute());
        assertEquals(15, result.getHour());
    }

    public void testEquals() throws Exception {
        assertTrue(time.equals(time));
        assertTrue(time.equals(new Time(13, 14)));
        assertTrue(new Time(13, 14).equals(time));
    }

    public void testGetHour() {
        assertEquals(13, time.getHour());
    }

    public void testGetMinute() {
        assertEquals(14, time.getMinute());
    }

    public void testIsLestThan() throws Exception {
        assertFalse(new Time(8, 17).isLessThan(new Time(8, 17)));
        assertTrue(new Time(8, 16).isLessThan(new Time(8, 17)));
    }

    public void testNewWithCurrentTime() {
        Time expected = new Time(21, 30);
        Time actual = new Time();
        assertEquals(expected, actual);
    }

    public void testSameHourAs() throws Exception {
        assertTrue(new Time(8, 17).sameHourAs(new Time(8, 7)));
        assertFalse(new Time(2, 15).sameHourAs(new Time(8, 17)));
    }

    public void testSameMinuteAs() throws Exception {
        assertTrue(new Time(2, 17).sameMinuteAs(new Time(8, 17)));
        assertFalse(new Time(2, 15).sameMinuteAs(new Time(8, 17)));
    }

    public void testStartOfHour() {
        assertEquals(new Time(13, 00), time.onTheHour());
    }

    public void testTitle() {
        assertEquals("13:14", time.titleString());
    }

    public void testToString() {
        assertEquals("13:14", time.toString());
    }

}
// Copyright (c) Naked Objects Group Ltd.
